@@ -154,7 +154,8 @@ gs.markov.blanket = function(x, data, nodes, alpha, B, whitelist, blacklist,
 
       if (debug) cat("  * checking node", y, "for inclusion.\n")
 
-      a = conditional.test(x, y, mb, data = data, test = test, B = B)
+      a = conditional.test(x, y, mb, data = data, test = test, B = B,
+            alpha = alpha)
 
       if (a <= alpha) {
 
@@ -203,7 +204,8 @@ gs.markov.blanket = function(x, data, nodes, alpha, B, whitelist, blacklist,
       if (debug)
         cat("  * checking node", y, "for exclusion (shrinking phase).\n")
 
-      a = conditional.test(x, y, mb[mb != y], data = data, test = test, B = B)
+      a = conditional.test(x, y, mb[mb != y], data = data, test = test, B = B,
+            alpha = alpha)
 
       if (a > alpha) {
 
