@@ -149,8 +149,8 @@ ia.markov.blanket = function(x, data, nodes, alpha, B, whitelist, blacklist,
   repeat {
 
     # get an association measure for each of the available nodes.
-    association = sapply(nodes, conditional.test, x, sx = mb,
-                    test = test, data = data, B = B)
+    association = sapply(nodes, conditional.test, x, sx = mb, test = test,
+                    data = data, B = B, alpha = alpha)
 
     if (debug) {
 
@@ -189,7 +189,8 @@ ia.markov.blanket = function(x, data, nodes, alpha, B, whitelist, blacklist,
     if (debug)
       cat("  * checking node", y, "for exclusion (shrinking phase).\n")
 
-    a = conditional.test(x, y, mb[mb != y], data = data, test = test, B = B)
+    a = conditional.test(x, y, mb[mb != y], data = data, test = test, B = B,
+          alpha = alpha)
 
     if (a > alpha) {
 
