@@ -4,18 +4,26 @@
     warning.level  = as.numeric(options("warn"))
     options("warn" = -1)
 
+    graphviz.enabled = lattice.enabled = FALSE
+
     # require the utils package explicitly.
     require(utils)
     # load graohviz and set the corresponding flag.
-    if ("Rgraphviz" %in% rownames(installed.packages()))
-      graphviz.enabled <<- require(Rgraphviz)
+    if ("Rgraphviz" %in% rownames(installed.packages())) {
+
+      require(grid)
+      require(graph)
+
+      graphviz.enabled = TRUE
+
+    }#THEN
 
     packageStartupMessage("Package Rgraphviz ",
-      ifelse(graphviz.enabled, "loaded successfully.", "not loaded."))
+      ifelse(graphviz.enabled, "will be loaded as needed.", "not loaded."))
 
     # load lattice and set the corresponding flag.
     if ("lattice" %in% rownames(installed.packages()))
-      lattice.enabled <<- require(lattice)
+      lattice.enabled = require(lattice)
 
     packageStartupMessage("Package lattice ",
       ifelse(lattice.enabled, "loaded successfully.", "not loaded."))
